from setuptools import setup

setup(name='calculating_distributions',
      version='1.3',
      description='Gaussian and Binomial Distributions',
      packages=['calculating_distributions'],
      author= 'Rodrigo Guarneros',
      author_email = 'rodrigo.guarneros@gmail.com',
      zip_safe=False)
